@@ -3,12 +3,11 @@
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #pragma once
 
-#include <QDBusPendingReply>
 #include <QObject>
+#include <QDBusPendingReply>
 
 #include <optional>
 
-#include <ModemManagerQt/Modem3Gpp>
 #include <ModemManagerQt/ModemDevice>
 #include <ModemManagerQt/ModemMessaging>
 #include <ModemManagerQt/Sms>
@@ -28,17 +27,10 @@ public:
 
     QString ownNumber();
 
-    QString ifaceName;
-
-    QString dnsServers;
-
-    QString countryCode;
-
 Q_SIGNALS:
     void messageAdded(ModemManager::Sms::Ptr message);
     void modemConnected();
     void modemDataConnectedChanged(const bool isConnected);
-    void countryCodeChanged(const QString &code);
 
 private Q_SLOTS:
     void slotMessageAdded(const QString &uni, bool received);
@@ -50,8 +42,4 @@ private:
     ModemManager::ModemDevice::Ptr m_modem;
     ModemManager::ModemMessaging::Ptr m_msgManager;
     ModemManager::Modem::Ptr m_interface;
-    ModemManager::Bearer::Ptr m_bearer;
-    ModemManager::Modem3gpp::Ptr m_modem3gpp;
-
-    QString getDNS(QSharedPointer<ModemManager::Bearer> bearer);
 };
