@@ -7,7 +7,11 @@
 #include <QObject>
 #include <QRegularExpression>
 
-#include <qofono-qt5/qofonosimmanager.h>
+#include <ModemManagerQt/Manager>
+#include <ModemManagerQt/Modem>
+#include <ModemManagerQt/ModemDevice>
+
+#include <phonenumberlist.h>
 
 class QQmlApplicationEngine;
 class QQuickWindow;
@@ -28,10 +32,22 @@ public:
     void showPassiveNotification(const QString &message, PassiveNotificationDuation timeout);
 
     Q_INVOKABLE bool isPhoneNumber(const QString &text) const;
-    Q_INVOKABLE bool isPremiumNumber(const QString &text) const;
+    Q_INVOKABLE bool isPremiumNumber(const PhoneNumberList &phoneNumberList) const;
     Q_INVOKABLE static void launchPhonebook();
     Q_INVOKABLE void copyTextToClipboard(const QString &text) const;
+    QString ownNumber();
     Q_INVOKABLE QString sendingNumber();
+    Q_INVOKABLE PhoneNumber phoneNumber(const QString &number) const;
+    Q_INVOKABLE PhoneNumberList phoneNumberList(const QStringList &phoneNumbers) const;
+
+    /// Currently only used to normalize contact model. Please try not to use this.
+    Q_INVOKABLE QString phoneNumberToInternationalString(const PhoneNumber &phoneNumber) const;
+
+    /// Currently only used to add a phone number to an image provider uri.
+    /// Please try not to use this.
+    Q_INVOKABLE QString phoneNumberListToString(const PhoneNumberList &phoneNumberList) const;
+
+    bool isLocale24HourTime();
 
     static QString textToHtml(const QString &text);
 
@@ -42,7 +58,7 @@ public:
     QQmlApplicationEngine *qmlEngine() const;
 
 private:
-    QOfonoSimManager *m_simManager;
     QQmlApplicationEngine *m_engine;
     QQuickWindow *m_window = nullptr;
+    PhoneNumber m_sendingNumber;
 };
